@@ -107,17 +107,12 @@ class IrcObject:
                 self.loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(self.loop)
 
-        # python 3.4.1 do not have a create_task method. check for it
-        self.create_task = getattr(self.loop, 'create_task', self.create_task)
+        self.create_task = self.loop.create_task
 
         self.registry = Registry()
 
         self.include(*self.config.get('includes', []))
 
-    def create_task(self, coro):  # pragma: no cover
-        # python 3.4.1 fallback
-        return asyncio.ensure_future(coro, loop=self.loop)
-
     def get_plugin(self, ob):
         plugins = self.registry.plugins
         includes = self.registry.includes
@@ -199,7 +194,7 @@ class IrcObject:
         scanner = self.venusian.Scanner(context=self)
         for module in modules:
             if module in reg.includes:
-                self.log.warn('%s included twice', module)
+                self.log.warning('%s included twice', module)
             else:
                 reg.includes.add(module)
                 try:
