@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import os
 import struct
 from collections import deque
 from functools import partial
@@ -14,9 +15,9 @@ class DCCBase(asyncio.Protocol):
     def __init__(self, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v)
-        self.ready = asyncio.Future(loop=self.loop)
-        self.started = asyncio.Future(loop=self.loop)
-        self.closed = asyncio.Future(loop=self.loop)
+        self.ready = self.loop.create_future()
+        self.started = self.loop.create_future()
+        self.closed = self.loop.create_future()
         self.timeout_handle = None
 
     def factory(self):
@@ -173,11 +174,8 @@ class DCCSend(DCCBase):
         raise NotImplementedError('write is not available during DCCSend')
 
     def send_chunk(self):
-        if self.sendfile:
-            sent = self.sendfile(self.fd, self.offset, self.block_size)
-        else:
-            self.fd.seek(self.offset)
-            sent = self.socket.send(self.fd.read(self.block_size))
+        sent = os.sendfile(self.socket.fileno(), self.fd_fileno,
+                           self.offset, self.block_size)
         return sent
 
     def next_chunk(self):
